@@ -1,19 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Matthias Ettrich (ettrich@kde.org)
-    Copyright (C) 2007 Lubos Lunak (l.lunak@kde.org)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Matthias Ettrich <ettrich@kde.org>
+    SPDX-FileCopyrightText: 2007 Lubos Lunak <l.lunak@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 /*
  * kwindowsystem.h. Part of the KDE project.
@@ -87,7 +77,7 @@ public:
      **/
     static bool hasWId(WId id);
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Returns information about window @p win. It is recommended to check
      * whether the returned info is valid by calling the valid() method.
@@ -97,9 +87,10 @@ public:
      *    in the returned data, but make this function faster when not all data is needed.
      * @param properties2 additional properties (see NET::Property2 enum)
      * @return the window information
-     * @deprecated use KWindowInfo directly
+     * @deprecated Since 5.0, use KWindowInfo directly
      */
-    KWINDOWSYSTEM_DEPRECATED static KWindowInfo windowInfo(WId win, NET::Properties properties, NET::Properties2 properties2 = NET::Properties2());
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowInfo(WId, NET::Properties, NET::Properties2")
+    static KWindowInfo windowInfo(WId win, NET::Properties properties, NET::Properties2 properties2 = NET::Properties2());
 #endif
 
     /**
@@ -224,6 +215,20 @@ public:
      */
     static void setOnActivities(WId win, const QStringList &activities);
 
+    /**
+     * Sets the parent window of @p subwindow to be @p mainwindow.
+     * This overrides the parent set the usual way as the QWidget or QWindow parent,
+     * but only for the window manager - e.g. stacking order and window grouping
+     * will be affected, but features like automatic deletion of children
+     * when the parent is deleted are unaffected and normally use
+     * the QObject parent.
+     *
+     * This function should be used before a dialog is shown for a window
+     * that belongs to another application.
+     */
+    static void setMainWindow(QWindow *subwindow, WId mainwindow);
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 62)
     /**
      * Sets the parent window of @p subwindow to be @p mainwindow.
      * This overrides the parent set the usual way as the QWidget parent,
@@ -234,24 +239,32 @@ public:
      *
      * This function should be used before a dialog is shown for a window
      * that belongs to another application.
+     * @deprecated since 5.62, use setMainWindow(QWindow *). If all you have is a QWidget*,
+     * you might need to call setAttribute(Qt::WA_NativeWindow, true); before calling
+     * >window()->windowHandle().
      */
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 62, "Use KWindowSystem::setMainWindow(QWindow *)")
     static void setMainWindow(QWidget *subwindow, WId mainwindow);
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Returns the WM_TRANSIENT_FOR property for the given window, i.e. the mainwindow
      * for this window.
      *
      * @param window the id of the window
-     * @deprecated Use KWindowInfo::transientFor
+     * @deprecated Since 5.0, use KWindowInfo::transientFor
      */
-    KWINDOWSYSTEM_DEPRECATED static WId transientFor(WId window);
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowInfo::transientFor()")
+    static WId transientFor(WId window);
 
     /**
      * Returns the leader window for the group the given window is in, if any.
      * @param window the id of the window
-     * @deprecated Use KWindowInfo::groupLeader
+     * @deprecated Since 5.0, use KWindowInfo::groupLeader
      */
-    KWINDOWSYSTEM_DEPRECATED static WId groupLeader(WId window);
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowInfo::groupLeader()")
+    static WId groupLeader(WId window);
 #endif
     /**
      * Returns an icon for window @p win.
@@ -345,7 +358,8 @@ public:
      * Possible values are or'ed combinations of NET::Modal,
      * NET::Sticky, NET::MaxVert, NET::MaxHoriz, NET::Shaded,
      * NET::SkipTaskbar, NET::SkipPager, NET::Hidden,
-     * NET::FullScreen, NET::KeepAbove, NET::KeepBelow, NET::StaysOnTop
+     * NET::FullScreen, NET::KeepAbove, NET::KeepBelow,
+     * NET::SkipSwitcher
      *
      * @param win the id of the window
      * @param state the new flags that will be set
@@ -358,7 +372,8 @@ public:
      * Possible values are or'ed combinations of NET::Modal,
      * NET::Sticky, NET::MaxVert, NET::MaxHoriz, NET::Shaded,
      * NET::SkipTaskbar, NET::SkipPager, NET::Hidden,
-     * NET::FullScreen, NET::KeepAbove, NET::KeepBelow, NET::StaysOnTop
+     * NET::FullScreen, NET::KeepAbove, NET::KeepBelow,
+     * NET::SkipSwitcher
      *
      * @param win the id of the window
      * @param state the flags that will be cleared
@@ -382,17 +397,19 @@ public:
      **/
     static void unminimizeWindow(WId win);
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @deprecated since 5.0 the @p animation is ignored.
      */
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowSystem::minimizeWindow(WId)")
     static void minimizeWindow(WId win, bool animation);
 #endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @deprecated since 5.0 the @p animation is ignored.
      */
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowSystem::unminimizeWindow(WId)")
     static void unminimizeWindow(WId win, bool animation);
 #endif
 
@@ -480,7 +497,7 @@ public:
      */
     static void setUserTime(WId win, long time);
     /**
-     * Sets the strut of window @p win to @p to @p left width
+     * Sets the strut of window @p win to @p left_width
      * ranging from @p left_start to @p left_end on the left edge,
      * and simiarly for the other edges. For not reserving a strut, pass 0 as the width.
      * E.g. to reserve 10x10 square in the topleft corner, use e.g.
@@ -689,9 +706,10 @@ Q_SIGNALS:
      * @param properties2 the properties2 that were modified
      *
      * @since 5.0
-     **/
-    void windowChanged(WId id, NET::Properties properties, NET::Properties2 properties2);
+     */
+    void windowChanged(WId id, NET::Properties properties, NET::Properties2 properties2); // clazy:exclude=overloaded-signal
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * The window changed.
      *
@@ -704,28 +722,34 @@ Q_SIGNALS:
      *
      * @deprecated since 5.0 use windowChanged(WId, NET::Properties, NET::Properties2)
      */
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
-    QT_MOC_COMPAT void windowChanged(WId id, const unsigned long *properties);
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowSystem::windowChanged(WId, NET::Properties, NET::Properties2)")
+    QT_MOC_COMPAT void windowChanged(WId id, const unsigned long *properties); // clazy:exclude=overloaded-signal
 #endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
-     * @deprecated
      * The window changed.
      *
      * The unsigned int parameter contains the NET properties that
      * were modified (see netwm_def.h).
      * @param id the id of the window
      * @param properties the properties that were modified
+     * @deprecated Since 5.0
      */
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
-    QT_MOC_COMPAT void windowChanged(WId id, unsigned int properties);
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 0, "Use KWindowSystem::windowChanged(WId, NET::Properties, NET::Properties2)")
+    QT_MOC_COMPAT void windowChanged(WId id, unsigned int properties); // clazy:exclude=overloaded-signal
 #endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 80)
     /**
      * The window changed somehow.
      * @param id the id of the window
-     */
-    void windowChanged(WId id);
+     *
+     * @deprecated since 5.80, use windowChanged(WId, NET::Properties, NET::Properties2);
+     **/
+    KWINDOWSYSTEM_DEPRECATED_VERSION(5, 80, "Use KWindowSystem::windowChanged(WId, NET::Properties, NET::Properties2)")
+    void windowChanged(WId id); // clazy:exclude=overloaded-signal
+#endif
 
     /**
      * The state of showing the desktop has changed.
@@ -747,7 +771,7 @@ Q_SIGNALS:
     void compositingChanged(bool enabled);
 
 protected:
-    void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
+    void connectNotify(const QMetaMethod &signal) override;
 
 private:
     friend class KWindowSystemStaticContainer;
